==> visualvm_2.0.6+dfsg.orig.tar.gz: visualvm-2.0.6/visualvm/jfr.generic/src/org/graalvm/visualvm/jfr/generic/model/impl/JFRGenericThread.java <==
/*
 * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.graalvm.visualvm.jfr.generic.model.impl;

import org.graalvm.visualvm.jfr.model.JFRThread;
import org.openjdk.jmc.common.IMCThread;

/**
 *
 * @author Jiri Sedlacek
 */
final class JFRGenericThread extends JFRThread {
    
    private final IMCThread thread;
    
    
    public JFRGenericThread(IMCThread thread) {
        this.thread = thread;
    }

    
    @Override
    public long getId() {
        // VM Thread throws NPE here
        try { return thread.getThreadId(); }
        catch (NullPointerException e) { return 0; }
    }

    @Override
    public String getName() {
        return thread.getThreadName();
    }
    
    
    @Override
    public int hashCode() {
        return thread.hashCode();
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof JFRGenericThread ? thread.equals(((JFRGenericThread)o).thread) : false;
    }
    
}

==> visualvm_2.2.orig.tar.gz: visualvm-2.2/visualvm/jfr.generic/src/org/graalvm/visualvm/jfr/generic/model/impl/JFRGenericThread.java <==
/*
 * Copyright (c) 2019, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.graalvm.visualvm.jfr.generic.model.impl;

import org.graalvm.visualvm.jfr.model.JFRThread;
import org.openjdk.jmc.common.IMCThread;

/**
 *
 * @author Jiri Sedlacek
 */
final class JFRGenericThread extends JFRThread {
    
    private final IMCThread thread;
    
    
    JFRGenericThread(IMCThread thread) {
        this.thread = thread;
    }

    
    @Override
    public long getId() {
        // VM Thread throws NPE here
        try { return thread.getThreadId(); }
        catch (NullPointerException e) { return 0; }
    }

    @Override
    public String getName() {
        return thread.getThreadName();
    }
    
    
    @Override
    public int hashCode() {
        return thread.hashCode();
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof JFRGenericThread ? thread.equals(((JFRGenericThread)o).thread) : false;
    }
    
}
